﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;

using System.IO;

// On the COM tab, add a reference to Microsoft Word 14.0 Object Library.
using Word = Microsoft.Office.Interop.Word;

namespace howto_docx_to_markdown2
{
    public partial class Form1 : Form
    {
        public Form1()
        {
            InitializeComponent();
        }

        private void mnuFileOpenFiles_Click(object sender, EventArgs e)
        {
            if (ofdFile.ShowDialog() == DialogResult.OK)
            {
                foreach (string filename in ofdFile.FileNames)
                {
                    AddFileToList(filename);
                }
                clbFiles.CheckAll();
            }
        }

        private void AddFileToList(string filename)
        {
            // See if the file is already in the list.
            foreach (FileData file_data in clbFiles.Items)
            {
                // If the file is in the list, do nothing.
                if (file_data.FileInfo.FullName == filename) return;
            }

            // Add the file to the list.
            clbFiles.Items.Add(new FileData(filename));
            clbFiles.SetItemChecked(clbFiles.Items.Count - 1, true);
        }

        private void mnuFileExit_Click(object sender, EventArgs e)
        {
            Close();
        }

        private void btnClear_Click(object sender, EventArgs e)
        {
            clbFiles.Items.Clear();
        }

        private void btnAll_Click(object sender, EventArgs e)
        {
            clbFiles.CheckAll();
        }

        private void btnNone_Click(object sender, EventArgs e)
        {
            clbFiles.UncheckAll();
        }

        private void btnGo_Click(object sender, EventArgs e)
        {
            // Get the Word application object.
            Word._Application word_app = new Word.Application();

            // Make Word visible (optional).
            //word_app.Visible = true;

            // Process the files.
            foreach (FileData file_data in clbFiles.CheckedItems)
            {
                ProcessFile(word_app, file_data.FileInfo.FullName);
            }

            // Close down Word.
            object save_changes = false;
            object missing = Type.Missing;
            word_app.Quit(ref save_changes, ref missing, ref missing);

            MessageBox.Show("Done");
        }

        private void ProcessFile(Word._Application word_app, string filename)
        {
            // Create the Word document.
            object missing = Type.Missing;
            object yes = true;
            object no = false;
            object filename_obj = filename;
            Word._Document word_doc = word_app.Documents.Open(
                ref filename_obj, ref missing, ref yes, ref no,
                ref missing, ref missing, ref missing, ref missing,
                ref missing, ref missing, ref missing, ref missing,
                ref missing, ref missing, ref missing, ref missing);

            string new_filename = filename.Replace(".docx", ".md");
            object new_filename_obj = new_filename;

            object txt_format = Word.WdSaveFormat.wdFormatText;
            word_doc.SaveAs2(ref new_filename_obj, ref txt_format,
                ref missing, ref missing, ref missing, ref missing,
                ref missing, ref missing, ref missing, ref missing,
                ref missing, ref missing, ref missing, ref missing,
                ref missing, ref missing, ref missing);

            object save_changes = false;
            word_doc.Close(ref save_changes, ref missing, ref missing);
        }

        private void Form1_Load(object sender, EventArgs e)
        {
            string[] args = Environment.GetCommandLineArgs();
            foreach (string filename in args)
            {
                if (!filename.ToLower().EndsWith(".exe"))
                    AddFileToList(filename);
            }
        }

        private void clbFiles_DragEnter(object sender, DragEventArgs e)
        {
            // See if this is a copy and the data includes text.
            if (e.Data.GetDataPresent(DataFormats.FileDrop) &&
                (e.AllowedEffect & DragDropEffects.Copy) != 0)
            {
                // Allow this.
                e.Effect = DragDropEffects.Copy;
            }
            else
            {
                // Don't allow any other drop.
                e.Effect = DragDropEffects.None;
            }
        }

        private void clbFiles_DragDrop(object sender, DragEventArgs e)
        {
            string[] filenames = (string[])e.Data.GetData(DataFormats.FileDrop);
            foreach (string filename in filenames)
                AddFileToList(filename);
        }
    }
}
